Define a two-stage multistage test
Arguments
- routing_b
Rasch difficulties of the routing module, in the order items would be dropped from the end when the module is shortened.
- modules
Named list of second-stage modules (difficulty vectors), ordered from easiest to hardest.
- cuts
Routing cuts on theta; by default the points where adjacent modules' information functions cross.